summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/wave.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/wave.cpp')
-rw-r--r--src/devices/sound/wave.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/devices/sound/wave.cpp b/src/devices/sound/wave.cpp
index 6506ef41d13..27407a2dbd2 100644
--- a/src/devices/sound/wave.cpp
+++ b/src/devices/sound/wave.cpp
@@ -43,16 +43,16 @@ void wave_device::device_start()
speaker_device_iterator spkiter(*owner());
int speakers = spkiter.count();
if (speakers > 1)
- machine().sound().stream_alloc(*this, 0, 2, machine().sample_rate());
+ stream_alloc_legacy(0, 2, machine().sample_rate());
else
- machine().sound().stream_alloc(*this, 0, 1, machine().sample_rate());
+ stream_alloc_legacy(0, 1, machine().sample_rate());
}
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void wave_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void wave_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
stream_sample_t *left_buffer = outputs[0];
stream_sample_t *right_buffer = nullptr;
@@ -43,16 +43,16 @@ void wave_device::device_start()
}
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------